Index: fltk/RadioItem.h
===================================================================
--- fltk/RadioItem.h	(revision 5923)
+++ fltk/RadioItem.h	(working copy)
@@ -28,7 +28,7 @@
 namespace fltk {
 
 /** This widget makes a radio item in a popup or pulldown Menu.
-    It's behavior in a Browser or other group is undefined. */
+    It's behavior in a Browser or MultiBrowser is that it changes its status on multiple clicks (e.g. double click). */
 class RadioItem : public Item {
 public:
   RadioItem(const char* label = 0) : Item(label) {type(RADIO);}
Index: fltk/ToggleItem.h
===================================================================
--- fltk/ToggleItem.h	(revision 5923)
+++ fltk/ToggleItem.h	(working copy)
@@ -28,7 +28,7 @@
 namespace fltk {
 
 /** This widget makes a checkmark in a popup or pulldown Menu.
-    It's behavior in a Browser or other group is undefined. */
+    It's behavior in a Browser or MultiBrowser is that it changes its status on multiple clicks (e.g. double click). */
 class ToggleItem : public Item {
 public:
   ToggleItem(const char* label = 0) : Item(label) {type(TOGGLE);}
Index: src/Item.cxx
===================================================================
--- src/Item.cxx	(revision 5923)
+++ src/Item.cxx	(working copy)
@@ -22,9 +22,11 @@
 //
 
 #include <fltk/Item.h>
+#include <fltk/Group.h>
 #include <fltk/Box.h>
 #include <fltk/CheckButton.h>
 #include <fltk/draw.h>
+#include <fltk/events.h>
 #include <string.h>
 
 using namespace fltk;
@@ -187,7 +189,20 @@
 
 /** Returns 0 always. Items do not accept \e any events. Any results
     of clicking on them is handled by the parent Menu or Browser. */
-int Item::handle(int) {return 0;}
+int Item::handle(int e) {
+	if (type() == TOGGLE) {
+		if (e == PUSH && event_clicks() > 0) state(!state());
+	} else if (type() == RADIO) {
+		if (e == PUSH && event_clicks() > 0) {
+			state(true);
+			Group *g = parent();
+			for (int n = 0; n < g->children(); n++) {
+				if (g->child(n) != this) g->child(n)->state(false);
+			}
+		}
+	}
+	return 0;
+}
 
 ////////////////////////////////////////////////////////////////
 
